@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Copyright 2021 The NATS Authors
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,9 +14,9 @@
 # limitations under the License.
 #
 
-require_relative 'msg/ack'
-require_relative 'msg/ack_methods'
-require_relative 'msg/metadata'
+require_relative "msg/ack"
+require_relative "msg/ack_methods"
+require_relative "msg/metadata"
 
 module NATS
   class JetStream
@@ -23,4 +25,9 @@ module NATS
     module Msg
     end
   end
-end
\ No newline at end of file
+
+  class Msg
+    # Enhance it with ack related methods from JetStream to ack msgs.
+    include JetStream::Msg::AckMethods
+  end
+end
